==> ruleset_checking_tool-0.1.0-py3-none-any.whl: rct229/rulesets/ashrae9012019/ruleset_functions/baseline_systems/is_baseline_system_9.py <==
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_cool_sources_none_or_null import (
    are_all_terminal_cool_sources_none_or_null,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_fans_null import (
    are_all_terminal_fans_null,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_heat_sources_none_or_null import (
    are_all_terminal_heat_sources_none_or_null,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_types_CAV import (
    are_all_terminal_types_cav,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.does_each_zone_have_only_one_terminal import (
    does_each_zone_have_only_one_terminal,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.does_hvac_system_serve_single_zone import (
    does_hvac_system_serve_single_zone,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.is_hvac_sys_cooling_type_none_or_non_mechanical import (
    is_hvac_sys_cooling_type_none_or_non_mechanical,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.is_hvac_sys_fan_sys_CV import (
    is_hvac_sys_fan_sys_cv,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.is_hvac_sys_heating_type_furnace import (
    is_hvac_sys_heating_type_furnace,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_system_util import (
    HVAC_SYS,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.is_baseline_system_9b import (
    is_baseline_system_9b,
)
from rct229.schema.schema_enums import SchemaEnums
from rct229.utils.utility_functions import has_preheat_system

HEATING_SYSTEM = SchemaEnums.schema_enums["HeatingSystemOptions"]


def is_baseline_system_9(rmi_b, hvac_b_id, terminal_unit_id_list, zone_id_list):
    """
    Get either Sys-9, Sys-9b, or Not_Sys_9 string output which indicates whether the HVAC system is ASHRAE 90.1 2019 Appendix G system 9 (Heating and Ventilation) or system 9b (system 9 with purchased heating).

    Parameters
     ----------
     rmi_b json
         To evaluate if the hvac system is modeled as either Sys-9, Sys-9b, or Not_Sys_9 in the B_RMI.
     hvac_b_id list
         The id of the hvac system to evaluate.
     terminal_unit_id_list
         List list of terminal unit IDs associated with the HVAC system to be evaluated. These are sent to this function from the master get_baseline_system_types function.
     zone_id_list list
         list of zone IDs associated with the HVAC system to be evaluated. These are sent to this function from the master get_baseline_system_types function.

    Returns
     -------
     The function returns either Sys-9, Sys-9b, or Not_Sys_9 string output which indicates whether the HVAC system is ASHRAE 90.1 2019 Appendix G system 9 (Heating and Ventilation) or system 9b (system 9 with purchased heating).
    """

    is_baseline_system_9 = HVAC_SYS.UNMATCHED

    if is_baseline_system_9b(rmi_b, hvac_b_id, terminal_unit_id_list, zone_id_list):
        is_baseline_system_9 = HVAC_SYS.SYS_9B
    else:
        # if preheat system DOESN'T exist, has_required_sys=True, else, False
        has_required_sys = not has_preheat_system(rmi_b, hvac_b_id)

        are_sys_data_matched = (
            # short-circuit the logic if no required data is found.
            has_required_sys
            # sub functions handles missing required sys, and return False.
            and is_hvac_sys_fan_sys_cv(rmi_b, hvac_b_id)
            and does_hvac_system_serve_single_zone(rmi_b, zone_id_list)
            and does_each_zone_have_only_one_terminal(rmi_b, zone_id_list)
            and are_all_terminal_heat_sources_none_or_null(rmi_b, terminal_unit_id_list)
            and are_all_terminal_cool_sources_none_or_null(rmi_b, terminal_unit_id_list)
            and are_all_terminal_fans_null(rmi_b, terminal_unit_id_list)
            and are_all_terminal_types_cav(rmi_b, terminal_unit_id_list)
            and is_hvac_sys_cooling_type_none_or_non_mechanical(rmi_b, hvac_b_id)
            and is_hvac_sys_heating_type_furnace(rmi_b, hvac_b_id)
        )

        if are_sys_data_matched:
            is_baseline_system_9 = HVAC_SYS.SYS_9

    return is_baseline_system_9

==> ruleset_checking_tool-0.3.0-py3-none-any.whl: rct229/rulesets/ashrae9012019/ruleset_functions/baseline_systems/is_baseline_system_9.py <==
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_cool_sources_none_or_null import (
    are_all_terminal_cool_sources_none_or_null,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_fans_null import (
    are_all_terminal_fans_null,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_heat_sources_none_or_null import (
    are_all_terminal_heat_sources_none_or_null,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.are_all_terminal_types_CAV import (
    are_all_terminal_types_cav,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.does_each_zone_have_only_one_terminal import (
    does_each_zone_have_only_one_terminal,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.does_hvac_system_serve_single_zone import (
    does_hvac_system_serve_single_zone,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.is_hvac_sys_cooling_type_none_or_non_mechanical import (
    is_hvac_sys_cooling_type_none_or_non_mechanical,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.is_hvac_sys_fan_sys_CV import (
    is_hvac_sys_fan_sys_cv,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_hvac_sub_functions.is_hvac_sys_heating_type_furnace import (
    is_hvac_sys_heating_type_furnace,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.baseline_system_util import (
    HVAC_SYS,
)
from rct229.rulesets.ashrae9012019.ruleset_functions.baseline_systems.is_baseline_system_9b import (
    is_baseline_system_9b,
)
from rct229.schema.schema_enums import SchemaEnums
from rct229.utils.utility_functions import has_preheat_system

HEATING_SYSTEM = SchemaEnums.schema_enums["HeatingSystemOptions"]


def is_baseline_system_9(rmd_b, hvac_b_id, terminal_unit_id_list, zone_id_list):
    """
    Get either Sys-9, Sys-9b, or Not_Sys_9 string output which indicates whether the HVAC system is ASHRAE 90.1 2019 Appendix G system 9 (Heating and Ventilation) or system 9b (system 9 with purchased heating).

    Parameters
     ----------
     rmd_b json
         To evaluate if the hvac system is modeled as either Sys-9, Sys-9b, or Not_Sys_9 in the B_RMD.
     hvac_b_id list
         The id of the hvac system to evaluate.
     terminal_unit_id_list
         List list of terminal unit IDs associated with the HVAC system to be evaluated. These are sent to this function from the master get_baseline_system_types function.
     zone_id_list list
         list of zone IDs associated with the HVAC system to be evaluated. These are sent to this function from the master get_baseline_system_types function.

    Returns
     -------
     The function returns either Sys-9, Sys-9b, or Not_Sys_9 string output which indicates whether the HVAC system is ASHRAE 90.1 2019 Appendix G system 9 (Heating and Ventilation) or system 9b (system 9 with purchased heating).
    """

    is_baseline_system_9 = HVAC_SYS.UNMATCHED

    if is_baseline_system_9b(rmd_b, hvac_b_id, terminal_unit_id_list, zone_id_list):
        is_baseline_system_9 = HVAC_SYS.SYS_9B
    else:
        # if preheat system DOESN'T exist, has_required_sys=True, else, False
        has_required_sys = not has_preheat_system(rmd_b, hvac_b_id)

        are_sys_data_matched = (
            # short-circuit the logic if no required data is found.
            has_required_sys
            # sub functions handles missing required sys, and return False.
            and is_hvac_sys_fan_sys_cv(rmd_b, hvac_b_id)
            and does_hvac_system_serve_single_zone(rmd_b, zone_id_list)
            and does_each_zone_have_only_one_terminal(rmd_b, zone_id_list)
            and are_all_terminal_heat_sources_none_or_null(rmd_b, terminal_unit_id_list)
            and are_all_terminal_cool_sources_none_or_null(rmd_b, terminal_unit_id_list)
            and are_all_terminal_fans_null(rmd_b, terminal_unit_id_list)
            and are_all_terminal_types_cav(rmd_b, terminal_unit_id_list)
            and is_hvac_sys_cooling_type_none_or_non_mechanical(rmd_b, hvac_b_id)
            and is_hvac_sys_heating_type_furnace(rmd_b, hvac_b_id)
        )

        if are_sys_data_matched:
            is_baseline_system_9 = HVAC_SYS.SYS_9

    return is_baseline_system_9
